@@ -70,10 +70,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         if self.request_delay is not None:
             time.sleep(self.request_delay)
@@ -128,14 +125,10 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"verifyFp": b.verifyFp, "_signature": b.signature}
         url = "{}&{}".format(b.url, urlencode(query))
-        print(b.did)
         r = requests.get(
             url,
             headers={
@@ -155,7 +148,7 @@ class TikTokApi:
         )
         return r.content
 
-    def trending(self, count=30, **kwargs) -> dict:
+    def trending(self, count=30, minCursor=0, maxCursor=0, **kwargs) -> dict:
         """
         Gets trending TikToks
         """
@@ -163,10 +156,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         response = []
@@ -194,7 +184,7 @@ class TikTokApi:
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy)
+            res = self.getData(b, **kwargs)
 
             for t in res.get("items", []):
                 response.append(t)
@@ -252,10 +242,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         response = []
@@ -274,7 +261,7 @@ class TikTokApi:
                 BASE_URL, prefix, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            data = self.getData(b, proxy=proxy)
+            data = self.getData(b, **kwargs)
 
             if "userInfoList" in data.keys():
                 for x in data["userInfoList"]:
@@ -294,7 +281,9 @@ class TikTokApi:
 
         return response[:count]
 
-    def userPosts(self, userID, secUID, count=30, **kwargs) -> dict:
+    def userPosts(
+        self, userID, secUID, count=30, minCursor=0, maxCursor=0, **kwargs
+    ) -> dict:
         """Returns a dictionary listing TikToks given a user's ID and secUID
 
         :param userID: The userID of the user, which TikTok assigns.
@@ -311,10 +300,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         response = []
@@ -343,7 +329,7 @@ class TikTokApi:
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy)
+            res = self.getData(b, **kwargs)
             if "items" in res.keys():
                 for t in res["items"]:
                     response.append(t)
@@ -376,30 +362,26 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
-        data = self.getUserObject(username, proxy=proxy)
+        data = self.getUserObject(username, **kwargs)
         return self.userPosts(
             data["id"],
             data["secUid"],
             count=count,
-            proxy=proxy,
-            language=language,
-            region=region,
             **kwargs,
         )
 
-    def userPage(self, userID, secUID, page_size=30, **kwargs) -> dict:
+    def userPage(
+        self, userID, secUID, page_size=30, minCursor=0, maxCursor=0, **kwargs
+    ) -> dict:
         """Returns a dictionary listing of one page of TikToks given a user's ID and secUID
 
         :param userID: The userID of the user, which TikTok assigns.
         :param secUID: The secUID of the user, which TikTok assigns.
         :param page_size: The number of posts to return per page.
-        :param after: time stamp for the earliest TikTok to retrieve
-        :param before: time stamp for the latest TikTok to retrieve
+        :param minCursor: time stamp for the earliest TikTok to retrieve
+        :param maxCursor: time stamp for the latest TikTok to retrieve
         :param language: The 2 letter code of the language to return.
                          Note: Doesn't seem to have an affect.
         :param region: The 2 letter region code.
@@ -410,10 +392,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         api_url = "https://m.tiktok.com/api/item_list/?{}&count={}&id={}&type=1&secUid={}" "&minCursor={}&maxCursor={}&sourceType=8&appId=1233&region={}&language={}".format(
@@ -427,15 +406,15 @@ class TikTokApi:
             language,
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)
+        return self.getData(b, **kwargs)
 
-    def getUserPager(self, username, page_size=30, **kwargs):
+    def getUserPager(self, username, page_size=30, minCursor=0, maxCursor=0, **kwargs):
         """Returns a generator to page through a user's feed
 
         :param username: The username of the user.
         :param page_size: The number of posts to return in a page.
-        :param after: time stamp for the earliest TikTok to retrieve
-        :param before: time stamp for the latest TikTok to retrieve
+        :param minCursor: time stamp for the earliest TikTok to retrieve
+        :param maxCursor: time stamp for the latest TikTok to retrieve
         :param language: The 2 letter code of the language to return.
                          Note: Doesn't seem to have an affect.
         :param region: The 2 letter region code.
@@ -446,23 +425,18 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
-        data = self.getUserObject(username, proxy=proxy)
+        data = self.getUserObject(username, **kwargs)
 
         while True:
             resp = self.userPage(
                 data["id"],
                 data["secUid"],
                 page_size=page_size,
-                before=maxCursor,
-                after=minCursor,
-                proxy=proxy,
-                language=language,
-                region=region,
+                maxCursor=maxCursor,
+                minCursor=minCursor,
+                **kwargs,
             )
 
             try:
@@ -478,7 +452,9 @@ class TikTokApi:
             if not resp["hasMore"]:
                 return  # all done
 
-    def userLiked(self, userID, secUID, count=30, **kwargs) -> dict:
+    def userLiked(
+        self, userID, secUID, count=30, minCursor=0, maxCursor=0, **kwargs
+    ) -> dict:
         """Returns a dictionary listing TikToks that a given a user has liked.
            Note: The user's likes must be public
 
@@ -496,10 +472,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         response = []
         first = True
@@ -527,7 +500,7 @@ class TikTokApi:
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy)
+            res = self.getData(b, **kwargs)
 
             try:
                 res["items"]
@@ -568,23 +541,17 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
-        data = self.getUserObject(username, proxy=proxy)
+        data = self.getUserObject(username, **kwargs)
         return self.userLiked(
             data["id"],
             data["secUid"],
             count=count,
-            proxy=proxy,
-            language=language,
-            region=region,
             **kwargs,
         )
 
-    def bySound(self, id, count=30, **kwargs) -> dict:
+    def bySound(self, id, count=30, offset=0, **kwargs) -> dict:
         """Returns a dictionary listing TikToks with a specific sound.
 
         :param id: The sound id to search by.
@@ -601,10 +568,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         response = []
 
@@ -615,30 +579,29 @@ class TikTokApi:
                 realCount = maxCount
 
             query = {
-                "count": realCount,
-                "id": id,
-                "type": 4,
                 "secUid": "",
-                "maxCursor": maxCursor,
-                "minCursor": minCursor,
+                "musicID": str(id),
+                "count": str(realCount),
+                "cursor": str(offset),
                 "shareUid": "",
                 "language": language,
             }
-            api_url = "{}share/item/list?{}&{}".format(
+            api_url = "{}api/music/item_list/?{}&{}".format(
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy)
+            res = self.getData(b, **kwargs)
 
-            for t in res["body"]["itemListData"]:
+            for t in res.get("itemList", []):
                 response.append(t)
 
-            if not res["body"]["hasMore"]:
-                print("TikTok isn't sending more TikToks beyond this point.")
+            if not res["hasMore"]:
+                if self.debug:
+                    print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
             realCount = count - len(response)
-            maxCursor = res["body"]["maxCursor"]
+            offset = res["cursor"]
 
         return response[:count]
 
@@ -654,10 +617,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         query = {"musicId": id, "language": language}
@@ -665,9 +625,9 @@ class TikTokApi:
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)
+        return self.getData(b, **kwargs)
 
-    def byHashtag(self, hashtag, count=30, **kwargs) -> dict:
+    def byHashtag(self, hashtag, count=30, offset=0, **kwargs) -> dict:
         """Returns a dictionary listing TikToks with a specific hashtag.
 
         :param hashtag: The hashtag to search by.
@@ -683,10 +643,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         id = self.getHashtagObject(hashtag)["challengeInfo"]["challenge"]["id"]
         response = []
@@ -696,7 +653,6 @@ class TikTokApi:
         while len(response) < required_count:
             if count > maxCount:
                 count = maxCount
-            added = 0
             query = {
                 "count": count,
                 "challengeID": id,
@@ -710,21 +666,21 @@ class TikTokApi:
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy, language=language)
+            res = self.getData(b, **kwargs)
 
             try:
                 for t in res["itemList"]:
                     response.append(t)
-                    added += 1
             except:
-                print(res)
+                if self.debug:
+                    print(res)
 
             if not res["hasMore"]:
                 if self.debug:
                     print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
-            offset += added
+            offset += maxCount
 
         return response[:required_count]
 
@@ -740,17 +696,14 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"challengeName": hashtag, "language": language}
         api_url = "{}api/challenge/detail/?{}&{}".format(
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)
+        return self.getData(b, **kwargs)
 
     def getHashtagDetails(self, hashtag, **kwargs) -> dict:
         """Returns a hashtag object.
@@ -764,19 +717,18 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"language": language}
         api_url = "{}node/share/tag/{}?{}&{}".format(
             BASE_URL, quote(hashtag), self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)
+        return self.getData(b, **kwargs)
 
-    def getRecommendedTikToksByVideoID(self, id, count=30, **kwargs) -> dict:
+    def getRecommendedTikToksByVideoID(
+        self, id, count=30, minCursor=0, maxCursor=0, **kwargs
+    ) -> dict:
         """Returns a dictionary listing reccomended TikToks for a specific TikTok video.
 
         :param id: The id of the video to get suggestions for.
@@ -788,10 +740,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         response = []
@@ -819,7 +768,7 @@ class TikTokApi:
                 BASE_URL, self.__add_new_params__(), urlencode(query)
             )
             b = browser(api_url, **kwargs)
-            res = self.getData(b, proxy=proxy)
+            res = self.getData(b, **kwargs)
 
             for t in res.get("items", []):
                 response.append(t)
@@ -848,10 +797,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         did = kwargs.get("custom_did", None)
         query = {
@@ -862,7 +808,7 @@ class TikTokApi:
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)
+        return self.getData(b, **kwargs)
 
     def getTikTokByUrl(self, url, **kwargs) -> dict:
         """Returns a dictionary of a TikTok object by url.
@@ -876,10 +822,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         custom_did = kwargs.get("custom_did", None)
         if "@" in url and "/video/" in url:
@@ -904,17 +847,14 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"noUser": 1, "userCount": 30, "scene": 0}
         api_url = "{}node/share/discover?{}&{}".format(
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)["body"][1]["exploreList"]
+        return self.getData(b, **kwargs)["body"][1]["exploreList"]
 
     def discoverMusic(self, **kwargs) -> dict:
         """Discover page, consists of music
@@ -925,17 +865,14 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"noUser": 1, "userCount": 30, "scene": 0}
         api_url = "{}node/share/discover?{}&{}".format(
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)["body"][2]["exploreList"]
+        return self.getData(b, **kwargs)["body"][2]["exploreList"]
 
     def getUserObject(self, username, **kwargs) -> dict:
         """Gets a user object (dictionary)
@@ -949,10 +886,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         return self.getUser(username, **kwargs)["user"]
 
@@ -968,17 +902,14 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {"uniqueId": username, "language": language}
         api_url = "{}api/user/detail/?{}&{}".format(
             BASE_URL, self.__add_new_params__(), urlencode(query)
         )
         b = browser(api_url, **kwargs)
-        return self.getData(b, proxy=proxy)["userInfo"]
+        return self.getData(b, **kwargs)["userInfo"]
 
     def getSuggestedUsersbyID(
         self, userId="6745191554350760966", count=30, **kwargs
@@ -993,10 +924,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {
             "noUser": 0,
@@ -1011,7 +939,7 @@ class TikTokApi:
         b = browser(api_url, **kwargs)
 
         res = []
-        for x in self.getData(b, proxy=proxy)["body"][0]["exploreList"]:
+        for x in self.getData(b, **kwargs)["body"][0]["exploreList"]:
             res.append(x["cardItem"])
         return res[:count]
 
@@ -1029,18 +957,13 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         users = []
         unusedIDS = [startingId]
         while len(users) < count:
             userId = random.choice(unusedIDS)
-            newUsers = self.getSuggestedUsersbyID(
-                userId=userId, language=language, proxy=proxy
-            )
+            newUsers = self.getSuggestedUsersbyID(userId=userId, **kwargs)
             unusedIDS.remove(userId)
 
             for user in newUsers:
@@ -1063,10 +986,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {
             "noUser": 0,
@@ -1081,7 +1001,7 @@ class TikTokApi:
         b = browser(api_url, **kwargs)
 
         res = []
-        for x in self.getData(b, proxy=proxy)["body"][1]["exploreList"]:
+        for x in self.getData(b, **kwargs)["body"][1]["exploreList"]:
             res.append(x["cardItem"])
         return res[:count]
 
@@ -1099,20 +1019,15 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         hashtags = []
         ids = self.getSuggestedUsersbyIDCrawler(
-            count=count, startingId=startingId, language=language, proxy=proxy
+            count=count, startingId=startingId, **kwargs
         )
         while len(hashtags) < count and len(ids) != 0:
             userId = random.choice(ids)
-            newTags = self.getSuggestedHashtagsbyID(
-                userId=userId["id"], language=language, proxy=proxy
-            )
+            newTags = self.getSuggestedHashtagsbyID(userId=userId["id"], **kwargs)
             ids.remove(userId)
 
             for hashtag in newTags:
@@ -1134,10 +1049,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         query = {
             "noUser": 0,
@@ -1152,7 +1064,7 @@ class TikTokApi:
         b = browser(api_url, **kwargs)
 
         res = []
-        for x in self.getData(b, proxy=proxy)["body"][2]["exploreList"]:
+        for x in self.getData(b, **kwargs)["body"][2]["exploreList"]:
             res.append(x["cardItem"])
         return res[:count]
 
@@ -1170,20 +1082,15 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         musics = []
         ids = self.getSuggestedUsersbyIDCrawler(
-            count=count, startingId=startingId, language=language, proxy=proxy
+            count=count, startingId=startingId, **kwargs
         )
         while len(musics) < count and len(ids) != 0:
             userId = random.choice(ids)
-            newTags = self.getSuggestedMusicbyID(
-                userId=userId["id"], language=language, proxy=proxy
-            )
+            newTags = self.getSuggestedMusicbyID(userId=userId["id"], **kwargs)
             ids.remove(userId)
 
             for music in newTags:
@@ -1202,10 +1109,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         try:
             api_url = data["video"]["downloadAddr"]
@@ -1226,10 +1130,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         b = browser(download_url, **kwargs)
         return self.getBytes(b, **kwargs)
@@ -1239,10 +1140,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
 
         tiktok_schema = self.getTikTokByUrl(video_url, **kwargs)
@@ -1262,10 +1160,7 @@ class TikTokApi:
             region,
             language,
             proxy,
-            minCursor,
-            maxCursor,
             maxCount,
-            offset,
         ) = self.__process_kwargs__(kwargs)
         r = requests.get(
             video_url,
@@ -1375,9 +1270,6 @@ class TikTokApi:
         region = kwargs.get("region", "US")
         language = kwargs.get("language", "en")
         proxy = kwargs.get("proxy", None)
-        maxCursor = kwargs.get("before", 0)
-        minCursor = kwargs.get("after", 0)
         maxCount = kwargs.get("maxCount", 35)
-        offset = kwargs.get("offset", 0)
 
-        return region, language, proxy, minCursor, maxCursor, maxCount, offset
+        return region, language, proxy, maxCount
